pytilities.delegation — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »

# pytilities.delegation

Delegation utilities

These utilities are a front-end to the aop package.

Contents

- DelegationAspect
- Profile
- in_profile()
- profile_carrier()

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »